# Camiba – Algorithms coming to Life

[![Issues](https://img.shields.io/github/issues/SebastianSemper/camiba.svg)](https://github.com/SebastianSemper/camiba/issues) [![Build Status](https://travis-ci.org/SebastianSemper/camiba.svg?branch=master)](https://travis-ci.org/SebastianSemper/camiba) [![License](https://img.shields.io/github/license/SebastianSemper/camiba.svg)]() [![Codacy Badge](https://api.codacy.com/project/badge/Grade/54806db2cc1144ddb0a7ef4ebe12fb39)](https://www.codacy.com/app/SebastianSemper/camiba?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=SebastianSemper/camiba&amp;utm_campaign=Badge_Grade)
## Installation

Clone or download this repository and invoke

```bash
python setup.py install
```

with the necessary user priviledges.

## Documentation

The documentation can be found at <https://sebastiansemper.github.io/camiba/>
or in the respective github pages branch of this repository. To build
the documentation yourself, invoke

```bash
python setup.py build_doc
```

and it will be placed in the `doc/html` subfolder.

## Affiliation

This package is currently developed and maintained at [TU Ilmenau](https://www.tu-ilmenau.de/) at the [EMS-Group](https://www.tu-ilmenau.de/it-ems/) and the [Institute of Mathematics](https://www.tu-ilmenau.de/math/).
